@@ -1,4 +1,5 @@
 from piper.verbs import to_tsv
+from piper.pandas import read_csv
 from piper.verbs import left_join
 from piper.verbs import duplicated
 from piper.verbs import resample_groupby
@@ -15,11 +16,10 @@ from piper.verbs import select
 from piper.verbs import where
 from piper.verbs import summarise
 from piper.verbs import info
-from piper.verbs import move_column
+from piper.verbs import relocate
 from piper.verbs import pivot_table
 from piper.verbs import tail
 from piper.verbs import trim
-from piper.verbs import add_jde_batch
 from piper.verbs import has_special_chars
 from piper.test.factory import get_sample_orders_01
 from piper.test.factory import get_sample_df1
@@ -114,35 +114,35 @@ def test_tail_with_dataframe(get_sample_df2):
 
 
 
-# test_move_column_single_column {{{1
-def test_move_column_single_column(get_sample_df2):
+# test_relocate_single_column {{{1
+def test_relocate_single_column(get_sample_df2):
     """
     """
     df = get_sample_df2
-    df = move_column(df, 'regions', loc='first')
+    df = relocate(df, 'regions', loc='first')
 
     expected = ['regions', 'ids']
     actual = df.columns.values.tolist()
     assert expected == actual
 
-# test_move_column_single_column_last_column {{{1
-def test_move_column_single_column_last_column(get_sample_df2):
+# test_relocate_single_column_last_column {{{1
+def test_relocate_single_column_last_column(get_sample_df2):
     """
     """
     df = get_sample_df2
-    df = move_column(df, 'regions', loc='last')
+    df = relocate(df, 'regions', loc='last')
 
     expected = ['ids', 'regions']
     actual = df.columns.values.tolist()
     assert expected == actual
 
 
-# test_move_column_multi_column_first {{{1
-def test_move_column_multi_column_first(get_sample_df1):
+# test_relocate_multi_column_first {{{1
+def test_relocate_multi_column_first(get_sample_df1):
     """
     """
     df = get_sample_df1
-    df = move_column(df, ['dates', 'regions', 'countries'], loc='first')
+    df = relocate(df, ['dates', 'regions', 'countries'], loc='first')
 
     expected = ['dates', 'regions', 'countries', 'order_dates',
                 'ids', 'values_1', 'values_2']
@@ -150,24 +150,24 @@ def test_move_column_multi_column_first(get_sample_df1):
     actual = df.columns.tolist()
     assert expected == actual
 
-# test_move_column_multi_column_last {{{1
-def test_move_column_multi_column_last(get_sample_df1):
+# test_relocate_multi_column_last {{{1
+def test_relocate_multi_column_last(get_sample_df1):
     """
     """
     df = get_sample_df1
-    df = move_column(df, ['dates', 'regions', 'countries'], loc='last')
+    df = relocate(df, ['dates', 'regions', 'countries'], loc='last')
 
     expected = ['order_dates', 'ids', 'values_1', 'values_2',
                 'dates', 'regions', 'countries' ]
     actual = df.columns.values.tolist()
     assert expected == actual
 
-# test_move_column_multi_column_before {{{1
-def test_move_column_multi_column_before(get_sample_df1):
+# test_relocate_multi_column_before {{{1
+def test_relocate_multi_column_before(get_sample_df1):
     """
     """
     df = get_sample_df1
-    df = move_column(df, ['dates', 'regions', 'countries'], loc='before',
+    df = relocate(df, ['dates', 'regions', 'countries'], loc='before',
                 ref_column='values_1')
 
     expected = ['order_dates', 'ids', 'dates', 'regions',
@@ -175,12 +175,12 @@ def test_move_column_multi_column_before(get_sample_df1):
     actual = df.columns.values.tolist()
     assert expected == actual
 
-# test_move_column_multi_column_after {{{1
-def test_move_column_multi_column_after(get_sample_df1):
+# test_relocate_multi_column_after {{{1
+def test_relocate_multi_column_after(get_sample_df1):
     """
     """
     df = get_sample_df1
-    df = move_column(df, ['dates', 'regions', 'countries'], loc='after',
+    df = relocate(df, ['dates', 'regions', 'countries'], loc='after',
                 ref_column='order_dates')
 
     expected = ['order_dates', 'dates', 'regions', 'countries',
@@ -713,17 +713,6 @@ def test_overlaps_no_price():
 
     assert expected == actual.shape
 
-# test_add_jde_batch {{{1
-def test_add_jde_batch(get_sample_df1):
-    """
-    """
-    dx = get_sample_df1
-    df = add_jde_batch(dx, inplace=False)
-
-    expected = (367, 11)
-    actual = df.shape
-
-    assert expected == actual
 
 # test_join_df {{{1
 def test_join_df(get_sample_df6):
@@ -1061,3 +1050,17 @@ def test_to_tsv_with_data(get_sample_orders_01):
 
     assert expected == actual
 
+
+# test_read_csv_with_data {{{1
+def test_read_csv_with_data(get_sample_orders_01):
+    """
+    """
+    file_name = 'piper/temp/to_tsv_with_data.tsv'
+    df_json = pd.DataFrame(get_sample_orders_01)
+
+    df = read_csv(file_name, sep='\t')
+
+    expected = df_json.shape
+    actual = df.shape
+
+    assert expected == actual
