@@ -4,15 +4,14 @@ import numpy as np
 import logging
 from functools import wraps
 from piper.io import _file_with_ext
+from piper.decorators import shape
 from pandas.core.common import flatten
 from datetime import datetime
 from piper.xl import WorkBook
+import logging
 
 logger = logging.getLogger(__name__)
 
-import logging
-logging.basicConfig(level=logging.INFO)
-
 
 # head() {{{1
 def head(df, n=4, info=True):
@@ -745,15 +744,15 @@ def rename_axis(df, *args, **kwargs):
     return df.rename_axis(*args, **kwargs)
 
 
-# move_column() {{{1
-def move_column(df, column=None, loc='last', ref_column=None):
-    ''' move_column: move column within a dataframe
+# relocate() {{{1
+def relocate(df, column=None, loc='last', ref_column=None):
+    ''' relocate: move column within a dataframe
 
     Example:
     --------
     %%piper
     df
-    >> move_column('FirstName', 'after', 'Department')
+    >> relocate('FirstName', 'after', 'Department')
     >> head()
 
     Parameters
@@ -901,9 +900,7 @@ def drop(df, *args, **kwargs):
     =======
     df <- pd.read_csv('inputs/export.dsv', sep='\t')
     >> clean_columns()
-    >> memory()
     >> trim()
-    >> memory()
     >> assign(adast = lambda x: x.adast.astype('category'),
               adcrcd = lambda x: x.adcrcd.astype('category'),
               aduom = lambda x: x.aduom.astype('category'))
@@ -969,56 +966,67 @@ def distinct(df, *args, **kwargs):
 
 
 # group_by() {{{1
-@wraps(pd.DataFrame.groupby)
+# @wraps(pd.DataFrame.groupby)
 def group_by(df, *args, **kwargs):
-    '''
+    ''' wrapper for pd.Dataframe.groupby() function
+
     Example:
     ========
-    (get_sample_data()
-     .pipe(where, "ids == 'A'")
-     .pipe(where, "values_1 > 300 & countries.isin(['Italy', 'Spain'])")
-     .pipe(group_by, ['countries', 'regions'])
-     .pipe(summarise, total_values_1=pd.NamedAgg('values_1', 'sum'))
-    )
+    %%piper
+
+    get_sample_data()
+    >> where("ids == 'A'")
+    >> where("values_1 > 300 & countries.isin(['Italy', 'Spain'])")
+    >> group_by(['countries', 'regions'])
+    >> summarise(total_values_1=pd.NamedAgg('values_1', 'sum'))
+
     '''
     return df.groupby(*args, **kwargs)
 
 
 # summarise() {{{1
-@wraps(pd.DataFrame.agg)
+# @wraps(pd.DataFrame.agg)
 def summarise(df=None, *args, **kwargs):
-    '''
-    Example:
+    ''' wrapper for pd.Dataframe.agg() function
+
+    Examples
     ========
-    %%piper
-    df >>
-    group_by([grouper, grouper2, 'ids']) >>
-    summarise(totval1=('values_1', 'sum'),
-              totval2=('values_2', 'sum')) >>
-    head()
+
+    # Syntax 1: column_name = ('existing_column', function)
+    # note: below there are some 'common' functions that can
+    # be quoted like 'sum', 'mean', 'count', 'nunique' or
+    # just state the function name
 
     %%piper
-    df >>
-    group_by([grouper, grouper2, 'ids']) >>
-    summarise(totval1=(pd.NamedAgg('values_1', 'sum')),
-              totval2=(pd.NamedAgg('values_2', 'sum'))) >>
-    head()
+    get_sample_sales() >>
+    group_by('product') >>
+    summarise(totval1=('target_sales', sum),
+              totval2=('actual_sales', 'sum'))
 
-    Conventional (pandas pipe method chaining)
-    (get_sample_data()
-     .pipe(where, "ids == 'A'")
-     .pipe(where, "values_1 > 300 & countries.isin(['Italy', 'Spain'])")
-     .pipe(group_by, ['countries', 'regions'])
-     .pipe(summarise, total_values_1=pd.NamedAgg('values_1', 'sum'))
-    )
 
-    Compress values into a list within a column and unpacking(via explode)
+    # Syntax 2: column_name = pd.NamedAgg('existing_column', function)
     %%piper
-    df >>
-    group_by('list') >>
-    summarise({'author': lambda x: x.tolist()}) >>
-    # explode('author') >>
-    head(6)
+    get_sample_sales() >>
+    group_by('product') >>
+    summarise(totval1=(pd.NamedAgg('target_sales', 'sum')),
+              totval2=(pd.NamedAgg('actual_sales', 'sum')))
+
+
+    # Syntax 3: {'existing_column': function}
+                {'existing_column': [function1, function2]}
+    %%piper
+    get_sample_sales()
+    >> group_by('product')
+    >> summarise({'target_sales':['sum', 'mean']})
+
+    # Syntax 4: 'existing_column': lambda x: x+1
+    # Example below identifies unique products sold by location.
+    %%piper
+    get_sample_sales() >>
+    group_by('location') >>
+    summarise({'product': lambda x: set(x.tolist())}) >>
+    # explode('product')
+
     '''
     if kwargs == {} and args == ():
         return df.agg('count')
@@ -1251,7 +1259,7 @@ def lookup(df, df2, columns=None, loc='last', ref_column=None, *args, **kwargs):
 
     # If columns specified, move them to requested dataframe column position.
     if columns is not None:
-        merged_df = move_column(merged_df, column=columns, loc=loc, ref_column=ref_column)
+        merged_df = relocate(merged_df, column=columns, loc=loc, ref_column=ref_column)
 
     return merged_df
 
@@ -1336,7 +1344,7 @@ def resample_groupby(df, index=None, grouper=None, rule='M'):
     g1 = df.groupby(index).sum()
     g1.reset_index(inplace=True)
 
-    logger.info(isinstance(grouper, list))
+    logger.debug(isinstance(grouper, list))
 
     if isinstance(grouper, list):
         for group_col in grouper:
@@ -1599,45 +1607,6 @@ def add_formula(df, column_name='xl_calc', formula='=CONCATENATE(A{row}, B{row},
     return df2
 
 
-# add_jde_batch() {{{1
-def add_jde_batch(df, col_prefix='ed', userid='userid',
-                  batch_prefix='ABC', start=100, step=100, inplace=False):
-    ''' Add 'standard' JDE timestamp/default column and values to
-    a dataframe - allowing it to be used (for example) for Z-file
-    upload.
-
-    Note: returns a copy of the given dataframe
-
-    Parameters
-    ----------
-    df : pandas dataframe
-
-    col_prefix : 2 character (e.g. 'ed') column name prefix
-
-    userid : default userid text value
-
-    batch_prefix : prefix used in xxbt column
-
-    start : start number in xxln column
-
-    step : step increment in xxln column
-
-    Returns
-    -------
-    pandas dataframe (copy)
-    '''
-    timestamp = datetime.now().strftime('_%Y%m%d')
-    start_position = 0
-
-    range_seq = range(start, (df.shape[0]+1)*step, step)
-    line_sequence = pd.Series(range_seq)
-
-    df.insert(start_position, f'{col_prefix}us', userid)
-    df.insert(start_position+1, f'{col_prefix}bt', batch_prefix + timestamp)
-    df.insert(start_position+2, f'{col_prefix}tn', 1)
-    df.insert(start_position+3, f'{col_prefix}ln', line_sequence)
-
-    return df
 
 
 # duplicated() {{{1
@@ -1690,7 +1659,7 @@ def duplicated(df=None, subset=None, keep=False, sort=True,
         dx[column] = duplicate_rows
 
         if loc is not None:
-           dx = move_column(dx, column=column, loc=loc, ref_column=ref_column)
+           dx = relocate(dx, column=column, loc=loc, ref_column=ref_column)
 
     if unique_only:
         dx = dx[~duplicate_rows]
@@ -1800,7 +1769,7 @@ def memory(df):
     memory = df.memory_usage(deep=True).sum()
     memory = round(memory / (1024 * 1024), 2)
 
-    msg = f'Dataframe with (rows, cols) {df.shape} consumes {memory} Mb'
+    msg = f'Dataframe consumes {memory} Mb'
     logger.info(msg)
 
     return df
@@ -1826,8 +1795,6 @@ def has_special_chars(df, col_name):
     return df
 
 
-
-
 # to_csv() {{{1
 @wraps(pd.DataFrame.to_csv)
 def to_csv(df, *args, **kwargs):
